fitLogVarLogMean: Second order polynomial fit of mean-variance dependence This...

View source: R/VarID_functions.R

fitLogVarLogMeanR Documentation

Second order polynomial fit of mean-variance dependence This function corrects for the systematic dependence of the variance on the mean by a local regression.

Description

Second order polynomial fit of mean-variance dependence This function corrects for the systematic dependence of the variance on the mean by a local regression.

Usage

fitLogVarLogMean(x)

Arguments

x

Matrix of transcript counts with genes as rows and cells as columns.

Value

Second order polynomial model as obtained by lm.


RaceID documentation built on Feb. 23, 2026, 9:07 a.m.