This functions returns an imputed expression matrix based on the imputing computed with compdist.
imputeexp(object, genes = NULL)SCseq class object.
vector of valid gene names corresponding to row names of slot ndata. Default is NULL and imputing is done for all genes.
An expression matrix with imputed expression values after size normalization. Genes are in rows and cells in columns.