plotsaturation: Plot Saturation of Within-Cluster Dispersion

View source: R/RaceID.R

plotsaturationR Documentation

Plot Saturation of Within-Cluster Dispersion

Description

This functions plots the (change in the) mean within-cluster dispersion as a function of the cluster number and highlights the saturation point inferred based on the saturation criterion applied by RaceID3: The number of clusters where the change in within-cluster dispersion upon adding further clusters approaches linear behaviour demarcates the saturation point and is highlighted in blue.

Usage

plotsaturation(object, disp = FALSE)

Arguments

object

SCseq class object.

disp

logical. If FALSE, then the change of the within-cluster dispersion is plotted. if TRUE the actual dispersion is plotted. Default is FALSE

Value

None


RaceID documentation built on Feb. 23, 2026, 9:07 a.m.